      subroutine write_config(config,npivots,allocated,fib,plog,
     :   slog,fibstatus,nfids,nobj,otype,scales,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        write_config
C
C     Invocation:
C        call write_config(config,npivots,allocated,fib,plog,
C           slog,fibstatus,nfids,nobj,otype,status)
C
C     Description:
C        Write the configuration to the output config file.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        config:  Integer (>)
C           The logical unit of the output configuration file
C        npivots:  Integer (>)
C           The total number of pivots
C        allocated:  Integer array (>)
C           The reference number of the object which has been allocated
C           to a particular fibre.
C        fib:  Integer array (>)
C           The current x,y position of each fibre button
C        plog:  Character array (>)
C           The log of information on each of the objects
C        slog:  Character array (>)
C           The log of information on each of the sky patches
C        fibstatus:  Integer array (>)
C           The fibre status (i.e. whether it's useable, disabled etc.)
C        nfids:  Integer (>)
C           The total number of fiducial objects in the original field file
C        nobj:  Integer (>)
C           The total number of objects
C        otype:  Integer array (>)
C           The object type (i.e. whether it's a program or sky)
C        scales:  Real array (>)
C           The field distortion coefficients 
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library subaf2_configure:
C           getval_i
C           rad2rd
C           rd2rad
C           rep_pl
C           xy2rd
C
C        Library chr:
C           chr_puti
C 
C        Library slalib:
C           sla_epj2d
C 
C     Algorithm:
C        -- Loop for all the pivots and check the value of the array 'allocated'
C        -- If allocated equals the cursor placement offset, then write the
C           name PLACE_XY as the object name.  Convert the x,y to RA,DEC and
C           write them out.
C        -- If allocated is greater than the sky offset then write the log 
C           information for the sky patch with the appropriate reference number
C        -- If allocated is greater than zero then write the log information
C           for the object with the appropriate reference number
C        -- If allocated is 0, -10, -20 or -30, then write PARKED, DISABLED,
C           DEAD, or MISSING respectively and nothing else.
C        -- If you want to include fiducials as references for af2_acquire,
C           then specify the number you want and then search the program log
C           for that number of fiducials.  Write out the log information for
C           these objects.  The 'pivot' numbers for these special cases go 
C           from 901 to 900 + n, where n is the number of fiducials you have
C           opted to include.
C        -- Report the number of placed objects.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
      include 'AF2_FSTA.INC'
      include 'AF2_MATH.INC'
C
C     Parameters
C
      integer config
      integer npivots
      integer allocated(npivots)
      integer fib(2,npivots)
      character plog(*)*80
      character slog(*)*80
      integer fibstatus(npivots)
      integer nfids
      integer nobj
      integer otype(*)
      real scales(*)
      integer status
C
C     Local variables
C
      integer i,j,len1,fid_wr,ih,im,ideg,ima,irah,iram,idd,idm
      character string*80,temp*10,fldlabel*80,centre*80,bundle*80
      character decsign*1
      real date,equinox,hour_ang,st,sa,sky_pa,ras,ds,x,y
      double precision ddate,dequinox,dhour_ang,dsc1,dsc2,dsc3
      double precision datej,cra,cdec,rot_ang,ra,dec
      logical first
C
C     Functions
C  
      double precision sla_epj2d
C
C     Common block with information read from the header of the field file
C
      common /fldhead/ fldlabel,date,equinox,hour_ang,ih,im,st,
     :   ideg,ima,sa,centre,sky_pa,bundle
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Set up a few things so that you can convert the cursor placed 
C     locations to RA,DEC
C
      ddate = dble(date)
      dequinox = dble(equinox)
      dhour_ang = dble(hour_ang)
      dsc1 = dble(scales(1))
      dsc2 = dble(scales(2))
      dsc3 = dble(scales(3))
      datej = sla_epj2d(ddate)
      call rd2rad(ih,im,st,ideg,ima,sa,centre,cra,cdec)
      rot_ang = (dble(sky_pa) - 90.0d0)*degtorad
      first = .true.
C
C     Now, loop through all pivots.  Write the appropriate line of 
C     information for each object type to the output string.
C
      do 10 i = 1,npivots
C
C        If this is a cursor placed location, then convert the x,y to
C        an RA, DEC.  Put the x,y next door.
C
         if (allocated(i) .eq. alloc_cur) then
            x = 0.001*real(fib(1,i))
            y = 0.001*real(fib(2,i))
            call xy2rd(x,y,dequinox,cra,cdec,dhour_ang,rot_ang,datej,
     :         dsc1,dsc2,dsc3,ra,dec,first,status)
            if (status .ne. af2_ok) go to 500
            call rad2rd(ra,dec,irah,iram,ras,idd,idm,ds,decsign)
            write(string,fmt=
     :         '(i3,1x,a,1x,2(i2.2,1x),f6.3,1x,a1,2(i2.2,1x),f6.3,2i9)')       
     :         i,'PLACE_XY',irah,iram,ras,decsign,idd,idm,ds,fib(1,i),
     :         fib(2,i)
C
C        If this is either a sky patch or an object, then put the 
C        logged information out.
C
         else if (allocated(i) .gt. alloc_sky) then
            write(string,fmt='(i3,1x,a74)') i,
     :         slog(allocated(i)-alloc_sky)
         else if (allocated(i) .gt. 0) then
            write(string,fmt='(i3,1x,a74)') i,plog(allocated(i))
C
C        If this fibre is not allocated for whatever reason, then write
C        out an excuse to matron.
C
         else if (allocated(i) .eq. 0) then
            write(string,fmt='(i3,1x,a)') i,'PARKED'
         else if (allocated(i) .eq. -10) then
            write(string,fmt='(i3,1x,a)') i,'DISABLED'
         else if (allocated(i) .eq. -20) then
            write(string,fmt='(i3,1x,a)') i,'DEAD'
         else if (allocated(i) .eq. -30) then
            write(string,fmt='(i3,1x,a)') i,'MISSING'
         end if
C
C        Write the output string to the config file.
C
         write(config,fmt='(a)') string
  10  continue
C
C     Now write out fiducial information for the acquire program.  The
C     user can specify how many may be required.
C
      len1 = 0
      call chr_puti(nfids,temp,len1)
      call getval_i('Number of fiducials required for acquire?',
     :   temp(:len1),'0',temp(:len1),fid_wr,status)
      if (status .ne. af2_ok) go to 500
C
C     Now loop through the object list until you have enough fiducial objects
C
      i = 0
      j = 0
      do while ((i .lt. nobj) .and. (j .lt. fid_wr))
         i = i + 1
C
C        If this is a fiducial, then write out the info to the config file.
C
         if (otype(i) .eq. fsta_fok) then
            j = j + 1
            write(config,fmt='(i3,1x,a74)') j+900,plog(i)
         end if
      end do
C
C     Finally, report on the number of objects placed
C
      call rep_pl(npivots,allocated,fibstatus,status)
C
C     Exit
C
  500 continue
      end
